<img src='https://github.com/WaylonWalker/creeper-adventure/blob/main/creeper_adventure/assets/stev/idle/0.png?raw=true' align="right">
<img src='https://github.com/WaylonWalker/creeper-adventure/blob/main/creeper_adventure/assets/bee/idle/1.png?raw=true' align="right">

# creeper-adventure

Creeper adventure is a top down 2d adventure game that I am building with my son using pygame.

[![PyPI - Version](https://img.shields.io/pypi/v/creeper-adventure.svg)](https://pypi.org/project/creeper-adventure)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/creeper-adventure.svg)](https://pypi.org/project/creeper-adventure)

-----

**Table of Contents**

- [Installation](#installation)
- [License](#license)

## Installation

```console
pip install creeper-adventure
```

## Running

```console
# run the game
creeper-adventure

# run in debug mode
creeper-adventure --debug

# see all options available
creeper-adventure --help
```

## running with pipx

`creeper-adventure` can also run using pipx if you have pipx installed.

```console
pipx run creeper-adventure
```

## Download an exe

pre-built binaries are available from the website [creeper-adventure](https://creeper-adventure.waylonwalker.com).

## License

`creeper-adventure` is distributed under the terms of the [MIT](https://spdx.org/licenses/MIT.html) license.
